---

slug: /dashboard-overview
---

# obshell Dashboard

obshell Dashboard is a Web-based visual management interface provided by OceanBase. It supports resource management of seekdb and provides monitoring capabilities for key resources and performance metrics, helping users efficiently manage seekdb.

The obshell Dashboard service is fully integrated into the obshell process. Users can manage seekdb by accessing the service address where obshell is deployed. This design simplifies the management process and ensures minimal resource overhead, providing a simple and user-friendly control experience.

## Features

The obshell Dashboard currently supports the following features for managing seekdb:

* Instance management: View instance information, including status, deployment specifications, creation/start time, working directory, and more. It also allows you to start/stop instances and modify instance allowlists. For more information, see [Manage instances](200.dashboard-instance.md).

* Database management: Manage databases under an instance. For more information, see [Manage databases](300.dashboard-db.md).

* User management: Manage users under an instance. For more information, see [Manage users](400.dashboard-user.md).

* Alarm center: View alarm rules and events for an instance and support shielding alarms. For more information, see [Manage alarms](500.dashboard-alarm.md).

* Performance monitoring: Monitor real-time **Performance and SQL**, **Transaction**, **Storage and Cache**, and **Host performance** metrics of a seekdb instance. For more information, see [Monitor performance](600.dashboard-monitor.md).

* Parameter management: View and modify parameters of a seekdb instance. For more information, see [Manage parameters](700.dashboard-parameter.md).

* Package management: Upload packages and upgrade obshell by uploading the target version of the package. For more information, see [Manage packages](800.dashboard-package.md).

* Task center: View and manage tasks generated during instance operations. For more information, see [Manage tasks](900.ob-dashboard-task.md).

## Log in and log off

obshell provides a graphical interface for visual management of seekdb. After successfully installing obshell, you can access the obshell Dashboard (the visual management page of obshell) by using the IP address and port number of an obshell node. By default, you log in as the root user, and the password is the password of the root user in the instance. If the root user password is empty, you can directly click **Login** to log in.

After logging in to the obshell Dashboard console, hover the cursor over the <span style={{ verticalAlign: 'middle' }}><img src="https://obbusiness-private.oss-cn-shanghai.aliyuncs.com/doc/img/observer-enterprise/V4.3.5/700.reference/1500.Components-and-Tools/100.obshell/500.icon/100.ob-dashboard-overview-01.png" alt="User" style={{ height: '20px' }}/></span> icon in the upper-right corner and click **Log out**. In the dialog box that appears, click **OK** to log off.

## View the version

After logging in to the obshell Dashboard console, click **Help** > **About obshell Dashboard** in the upper-right corner to view the version of obshell Dashboard.
